package edu.uoc.pfc.anonymous;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import edu.uoc.pfc.anonymous.msg.ErrorMessages;
import edu.uoc.pfc.anonymous.msg.InfoMessages;
import edu.uoc.pfc.anonymous.provider.ProfileProvider;
import edu.uoc.pfc.profile.data.Profile;
import edu.uoc.pfc.profile.xml.ProfileXMLHelper;
import edu.uoc.pfc.search.GoogleSearchGenerator;
import edu.uoc.pfc.search.SearchGenerator;
import edu.uoc.pfc.service.AnonymousQueriesService;
import edu.uoc.pfc.service.exception.AnonymousQueryServiceException;


/**
 * Programa executable amb el qual es possar en marxa el servei de enviament de consultes 
 * annimes al motor de cerca.
 * 
 * @author Rubn Salvador Gareta
 *
 */
public class AnonymousQueriesServiceStart {
	
	/**
	 * Variable que ser utilitzada per a escriure missatges en el log de la aplicaci.
	 */
	private static final Logger LOGGER =
	        LoggerFactory.getLogger(AnonymousQueriesServiceStart.class);

	/**
	 * Mtode principal que s'executar per a inicialitzar el servei.
	 * 
	 * @param args [0] Tipus de xarxa social
	 *  		   [1] Fitxer amb les propietats del KeyStore de l'usuari.
	 *  		   [2] Port en el qual s'ha de possar en marxa el servei.
	 *  		   [3] (Opcional) Fitxer amb les propietats de la base de dades de la 
	 *  			   xarxa social.
	 */
	public static void main(String[] args){
		
		try {
			LOGGER.info(InfoMessages.PROCESS_START.getValue());			
			if((args.length == 3) || (args.length == 4)){
				// Obtenci de les dades del perfil d'usuari en funci de la xarxa
				// social a la que l'usuari es vol connectar.
				ProfileProvider provider = new ProfileProvider();
				ProfileXMLHelper xmlHelper = provider.getProfileXMLHelper(args);
				Profile profile = provider.getProfile(args, xmlHelper);
				
				// Si l'usuari t perfil a la xarxa social es possa en marxa el protocol
				// de cerca.
				if(profile != null){
					LOGGER.info(InfoMessages.USER_FOUND.getValue(), profile.getUser().getUserId());
					SearchGenerator search = new GoogleSearchGenerator();
					AnonymousQueriesService service = new AnonymousQueriesService();
					service.start(profile, search, xmlHelper);					
				}				
			} else {
				LOGGER.error(ErrorMessages.USAGE_SERVICE.getValue());
			}			
		} catch (AnonymousQueryServiceException e) {
			LOGGER.error(ErrorMessages.ERROR_SERVICE.getValue());
		}
	}
	
}
