package edu.uoc.pfc.profile.xml;

import java.io.File;

import edu.uoc.pfc.profile.data.Profile;
import edu.uoc.pfc.profile.exception.ProfileException;


/**
 * Classe abstracta amb els mtodes necessaris per a mantenir actualitzat el fitxer XML corresponent al perfil 
 * de l'usuari dins del protocol de cerques annimes. Els mtodes no implementats hauran de ser implementats 
 * d'una forma especfica en funci de la xarxa social que s'estigui fent servir.
 * 
 * @author Rubn Salvador Gareta
 *
 */
public abstract class ProfileXMLHelper {
	
	public static String PROFILE_XML = "./logs/profile.xml";
	
	/**
	 *
	 * Mtode encarregat d'obtenir un fitxer XML amb les dades del perfil d'usuari a partir
	 * de les dades d'identificaci de l'usuari dins la xarxa social.
	 * 
	 * @param ipAddress Adrea IP de l'usuari.
	 * @param port Port de connexi de l'usuari.
	 * @param file Fitxer on s'escriur l'XML obtingut.
	 * @return Objecte Profile amb les dades del perfil d'usuari.
	 * @throws ProfileException
	 */
	public abstract Profile downloadProfile(String ipAddress, String port, File file) throws ProfileException;
	

	/**
	 * Mtode encarregat d'actualitzar el fitxer XML amb les noves dades del perfil d'usuari a 
	 * partir de les dades d'identificaci de l'usuari dins la xarxa social.
	 * 
	 * @param ipAddress  Adrea IP de l'usuari.
	 * @param port Port de connexi de l'usuari.
	 * @param file Fitxer que cont l'XML que s'ha d'actualitzar.
	 * @throws ProfileException
	 */
	public abstract Profile updateProfile(String ipAddress, String port, File file) throws ProfileException;
	
	
	/**
	 * Mtode encarregat de guardar un objecte Profile amb les dades del perfil 
	 * d'usuari en un fitxer.
	 * 
	 * @param profile Objecte Profile amb les dades del perfil d'usuari.
	 * @param file Fitxer en el qual es vol guardar el perfil d'usuari.
	 * @throws ProfileException
	 */
	public void saveProfile(Profile profile, File file) throws ProfileException {
		ProfileXMLParser parser = new ProfileXMLParser();
		parser.profileToXMLFile(profile, file);
	}
	
}
