package edu.uoc.pfc.search;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.net.URLConnection;

import org.apache.commons.io.IOUtils;

import edu.uoc.pfc.search.exception.SearchGeneratorException;
import edu.uoc.pfc.search.msg.ErrorMessages;

/**
 * Classe abstracta que deixa sense implementar el mtode d'obtenci 
 * dels resultats de la consulta que depen del propi cercador que 
 * s'utilitci.
 * 
 * @author Rubn Salvador Gareta
 *
 */
public abstract class SearchGenerator {
	
	/**
	 * Mtode abstracte que ser implementat per les diferents classes 
	 * que hereten d'aquesta classe en funci del cercador utilitzat.
	 * 
	 * @param query Consulta que es vol enviar cap al cercador.
	 * @return Resultat de la cerca.
	 * @throws SearchGeneratorException 
	 */
	public abstract String getQueryResult(String query) throws SearchGeneratorException; 
	
	/**
	 * Mtode a travs del qual s'estableix la connexi amb una URL 
	 * concreta i retorna el resultat en forma de cadena de carcters.
	 * 
	 * @param conn Connexi amb la URL del cercador amb els seus parmetres.
	 * @return Resultat que retorna la connexi.
	 * @throws SearchGeneratorException 
	 */
	protected String sendQuery(URLConnection conn) throws SearchGeneratorException{
		String answer = null;
		InputStream is = null;
		InputStreamReader isr = null;
		BufferedReader rd = null;
		
		try{
			// Obtenci de la resposta del cercador.
			is = conn.getInputStream();
			isr = new InputStreamReader(is);
			rd = new BufferedReader(isr);
			StringBuffer sb = new StringBuffer();
			String line;
			while((line = rd.readLine()) != null) {
				sb.append(line);
			}
			answer = sb.toString();
			
		} catch (IOException e) {
			throw new SearchGeneratorException(
					ErrorMessages.ERROR_COMMUNICATION.getValue(), e);
		} finally {
			if(rd != null) {
				IOUtils.closeQuietly(rd);
			}
			if(isr != null){
				IOUtils.closeQuietly(isr);
			}
			if(is != null){
				IOUtils.closeQuietly(is);
			}			
		}
		return answer;
	}

}
