package edu.uoc.pfc.service;

import java.net.MalformedURLException;
import java.rmi.Naming;
import java.rmi.NotBoundException;
import java.rmi.RemoteException;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import edu.uoc.pfc.profile.data.Profile;
import edu.uoc.pfc.service.msg.ErrorMessages;
import edu.uoc.pfc.service.msg.InfoMessages;
import edu.uoc.pfc.service.rmi.AnonymousQueriesRemote;
import edu.uoc.pfc.transaction.TransactionCertificateHelper;
import edu.uoc.pfc.user.data.User;

/**
 * Classe que fa de client del servei remot RMI i a travs de la qual es crida
 * al mtode remot del servei.
 * 
 * @author Rubn Salvador Gareta
 *
 */
public class AnonymousQueriesClient {
	
	/**
	 * Objecte que cont les dades del perfil d'usuari necessries per a
	 * a possar en marxa el protocol de cerques annimes.
	 */
	private Profile profile;
	
	/**
	 * Objecte d'utilitats relacionades amb la generaci i validaci de certificats 
	 * de transacci
	 */
	private TransactionCertificateHelper transactionHelper; 
	
	/**
	 * Variable que ser utilitzada per a escriure missatges en el log de la aplicaci.
	 */
	private static final Logger LOGGER =
	        LoggerFactory.getLogger(AnonymousQueriesClient.class);
	
	/**
	 * Mtode constructor.
	 * 
	 * @param profile Objecte que cont les dades del perfil d'usuari necessries per a
	 * a possar en marxa el protocol de cerques annimes.	
	 * @param transactionHelper Objecte d'utilitats relacionades amb la generaci i validaci 
	 * de certificats 
	 * de transacci.
	 */
	public AnonymousQueriesClient(Profile profile, TransactionCertificateHelper transactionHelper){
		this.profile = profile;
		this.transactionHelper = transactionHelper;							
	}
	
	/**
	 * Mtode amb el qual s'envia la consulta a un contacte concret i retorna el resultat de
	 * de la cosulta.
	 * 
	 * @param destContact Identificador de l'usuari destinatari de la consulta.
	 * @param query consultq que es vol enviar.
	 * @return Resultat de la consulta.
	 */
	public String sentQueryToContact(User destContact, String query) {
		try{
			// Generar el certificat de transacci de la consulta.
			String transCert = transactionHelper.generateTransactionCertificate(query,
													destContact.getUserId(), profile.getKeystore(), 
													profile.getAlias(), profile.getPassword());
			
			LOGGER.info(InfoMessages.QUERY_SENT_USER.getValue(), destContact.getUserId()); 
			
			// Localitzar el servei del usuari destinatari de la consulta
			String url = AnonymousQueriesRemote.PROTOCOL + destContact.getUserId() 
														+ AnonymousQueriesRemote.SERVICE;
			AnonymousQueriesRemote anonymous = (AnonymousQueriesRemote)Naming.lookup(url);		
			
			// Enviar la petici i esperar la resposta.
			String answer = anonymous.getAnswer(query, transCert, profile.getUser().getUserId());
			return answer;	
			
		} catch(RemoteException e){
			LOGGER.error(ErrorMessages.ERROR_CONNECTION.getValue(), e);
			return null;
		} catch (MalformedURLException e) {
			LOGGER.error(ErrorMessages.ERROR_URL_FORMAT.getValue(), e);
			return null;
		} catch (NotBoundException e) {
			LOGGER.error(ErrorMessages.ERROR_CONNECTION.getValue(), e);
			return null;
		} 	
	}

}
