package edu.uoc.pfc.social;

import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;

import org.apache.commons.io.IOUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import edu.uoc.pfc.social.exception.SocialNetworkException;
import edu.uoc.pfc.social.msg.ErrorMessages;


/**
 * Programa executable amb el qual s'inicialitzar la xarxa social per primera vegada
 * a partir del fitxer XML de configuraci de la xarxa social i del fitxer de propietats 
 * de la base de dades.
 * 
 * @author Rubn Salvador Gareta
 *
 */
public class SocialNetworkStart {

	/**
	 * Variable que ser utilitzada per a escriure missatges en el log de la aplicaci.
	 */
	private static final Logger LOGGER =
	        LoggerFactory.getLogger(SocialNetworkStart.class);
	
	/**
	 * Mtode principal que s'executar per a inicialitzar la xarxa social.
	 * 
	 * @param args [0] Fitxer amb la configuraci de la xarxa social en format XML.
	 *  		   [1] Fitxer amb les propietats de la base de dades de la xarxa social.
	 * @throws SocialNetworkException 
	 */
	public static void main(String[] args) throws SocialNetworkException {
		InputStream socialNetworkXml = null;
		InputStream dbProperties = null;
		try {
			if(args.length == 2){
				String socialPath = args[0];
				String dbPropsPath =  args[1];
				socialNetworkXml = new FileInputStream(socialPath);
				dbProperties = new FileInputStream(dbPropsPath);
				SocialNetwork socialNetwork = new SocialNetwork(socialNetworkXml, dbProperties);
				socialNetwork.init();	
				socialNetwork.close();
			} else {
				LOGGER.error(ErrorMessages.USAGE.getValue());
			}
		} catch (IOException e) {
			LOGGER.error(ErrorMessages.ERROR_INPUT_FILES.getValue(), e);
		} finally {
			if(socialNetworkXml != null){
				IOUtils.closeQuietly(socialNetworkXml);
			}			
			if(dbProperties != null){
				IOUtils.closeQuietly(dbProperties);
			}
		}
	}
	
}
