package edu.uoc.pfc.social.data;

import java.util.List;

/**
 * Classe encarregada de emmagatzemar les dades de la taula USER de 
 * la base dedes.
 * 
 * @author Rubn Salvador Gareta
 *
 */
public class UserEntity {
	
	/**
	 * Identificador nic de l'usuari dins de la base de dades
	 */
	private String id;
	
	/**
	 * Addrea IP del usuari.
	 */
	private String ipAddress;
	
	/**
	 * Port de connexi de l'usuari
	 */
	private String port;
	
	/**
	 * Certificat de l'usuari codificat en Base64.
	 */
	private String certificate;
	
	/**
	 * Llista d'indentificadors dels contactes de l'usuari.
	 */
	private List<String> contactIdList;
	

	/**
	 * Mtode amb el qual s'obt l'identificador nic de l'usuari 
	 * dins de la base de dades.
	 *  
	 * @return Identificador nic de l'usuari dins de la base de dades.
	 */
	public String getId() {
		return id;
	}

	/**
	 * Mtode amb el qual s'estableix l'identificador nic de l'usuari 
	 * dins de la base de dades.
	 * 
	 * @param id Identificador nic de l'usuari dins de la base de 
	 * dades.
	 */
	public void setId(String id) {
		this.id = id;
	}

	/**
	 * Mtode amb el qual s'obt l'addrea IP del usuari.
	 *  
	 * @return Addrea IP del usuari.
	 */
	public String getIpAddress() {
		return ipAddress;
	}

	/**
	 * Mtode amb el qual s'estableix l'addrea IP del usuari.
	 * 
	 * @param ipAddress Addrea IP del usuari
	 */
	public void setIpAddress(String ipAddress) {
		this.ipAddress = ipAddress;
	}

	/**
	 * Mtode amb el qual s'obt el port de connexi de l'usuari.
	 *  
	 * @return Port de connexi de l'usuari.
	 */
	public String getPort() {
		return port;
	}

	/**
	 * Mtode amb el qual s'estableix port de connexi de l'usuari.
	 * 
	 * @param port Port de connexi de l'usuari.
	 */
	public void setPort(String port) {
		this.port = port;
	}

	/**
	 * Mtode amb el qual s'obt el certificat de l'usuari codificat 
	 * en Base64.
	 *  
	 * @return Certificat de l'usuari codificat en Base64.
	 */
	public String getCertificate() {
		return certificate;
	}

	/**
	 * Mtode amb el qual s'estableix el certificat de l'usuari 
	 * codificat en Base64.
	 * 
	 * @param certificate Certificat de l'usuari codificat en Base64.
	 */
	public void setCertificate(String certificate) {
		this.certificate = certificate;
	}
	
	/**
	 * Mtode amb el qual s'obt la llista d'indentificadors dels 
	 * contactes de l'usuari.
	 *  
	 * @return Llista d'indentificadors dels contactes de l'usuari.
	 */
	public List<String> getContactIdList() {
		return contactIdList;
	}

	/**
	 * Mtode amb el qual s'estableix la llista d'indentificadors dels 
	 * contactes de l'usuari.
	 * 
	 * @param contactIdList Llista d'indentificadors dels contactes de l'usuari.
	 */
	public void setContactIdList(List<String> contactIdList) {
		this.contactIdList = contactIdList;
	}
	
	

}
