package edu.uoc.pfc.social.db;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Map.Entry;

import edu.uoc.pfc.social.data.UserEntity;
import edu.uoc.pfc.social.exception.DatabaseException;
import edu.uoc.pfc.social.msg.ErrorMessages;

/**
 * Classe encarregada de gestionar les operacions de base de dades relacionades 
 * amb la taula Contacts. 
 * 
 * @author Rubn Salvador Gareta
 *
 */
public class ContactsDAO extends EntityDAO {
	
	/**
	 * Mtode constructor.
	 * 
	 * @param conn Connexi amb la base de dades.
	 */
	public ContactsDAO(Connection conn){
		super(conn);
	}
	
	
	/**
	 * Mtode amb el qual s'insertar una srie de relacions entre usuaris
	 * dins de la taula Contact
	 * 
	 * @param userList Llista d'usuaris.
	 * @throws DatabaseException 
	 */
	public void insertContacts(Map<String, UserEntity> userList) 
														throws DatabaseException{
		PreparedStatement ps = null;
		try{
			String sql = "INSERT INTO contacts (user_id, contact_id) VALUES (?, ?)";
			ps = getConn().prepareStatement(sql);
			
			Iterator<Entry<String, UserEntity>> it = userList.entrySet().iterator();
		    while (it.hasNext()) {
		        Map.Entry<String, UserEntity> pairs = 
		        		(Map.Entry<String, UserEntity>)it.next();
		        UserEntity user = (UserEntity) pairs.getValue();
		        List<String> contactIdList = user.getContactIdList();
		        for(String contactId: contactIdList){
					if(userList.containsKey(contactId)){
						ps.setString(1, user.getId());
						ps.setString(2, contactId);
						ps.executeUpdate();
					} else {
						throw new DatabaseException(
							ErrorMessages.ERROR_DB_INSERT_CONTACTS.getValue());
					}
				}
		    }			
		} catch (SQLException e) {
			throw new DatabaseException(
						ErrorMessages.ERROR_DB_INSERT_CONTACTS.getValue(), e);
		} finally {
			closePreparedStatement(ps);
		}
	}
	
	/**
	 * Mtode utilitzat per obtenir de la base de dades la llista d'identificadors de contacte
	 * d'un usuari a partir del seu identificador.
	 * 
	 * @param userId Identificador de usuari.
	 * @return Llista d'identificadors d'usuari.
	 * @throws DatabaseException
	 */
	public List<String> getContactsIdListByUserId(String userId) throws DatabaseException{
		List<String> contactIdList = null;
		ResultSet rs = null;
		PreparedStatement ps = null;
		String sql = "SELECT * FROM contacts WHERE user_id=?";
		
		try{
			ps = getConn().prepareStatement(sql);
			ps.setString(1, userId);
			rs = ps.executeQuery();
			
			contactIdList = new ArrayList<String>();
			while (rs != null && rs.next()) {
				contactIdList.add(rs.getString("contact_id"));
            }
		} catch(SQLException e){
			throw new DatabaseException(
					ErrorMessages.ERROR_DB_SELECT_CONTACTS.getValue(), e);
		} finally {
			closeResultSet(rs);
			closePreparedStatement(ps);
		}
		return contactIdList;
		
	}

}
