package edu.uoc.pfc.social.db;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;

import edu.uoc.pfc.social.exception.DatabaseException;
import edu.uoc.pfc.social.msg.ErrorMessages;

/**
 * Classe encarregada de implementar les funcionalitats genriques de tots els DAO.
 * 
 * @author Rubn Salvador Gareta
 *
 */
public class EntityDAO {
	
	/**
	 * Database connection.
	 */
	private Connection conn;
	
	/**
	 * Mtode constructor.
	 * @param conn Connexi amb la base de dades
	 */
	public EntityDAO (Connection conn){
		this.conn = conn;
	}
	
	/**
	 * Mtode utilitat per accedir a la connexi
	 * 
	 * @return Connexi a la base de dades.
	 */
    protected Connection getConn() {
        return conn;
    }
    
	/**
	 * Mtode privat encarregat de tancar un PreparedStatement.
	 * 
	 * @throws DatabaseException 
	 */
	protected void closePreparedStatement(final PreparedStatement ps) 
												throws DatabaseException {
        try {
            if (ps != null) {
                ps.close();
            }           
        } catch (SQLException e) {
        	throw new DatabaseException(
        					ErrorMessages.ERROR_DB_INSERT.getValue(), e);
        }
    }
	
	/**
	 * Mtode privat encarregat de tancar un ResultSet.
	 * 
	 * @throws DatabaseException 
	 */
	protected void closeResultSet(final ResultSet rs) 
												throws DatabaseException {
        try {
            if (rs != null) {
                rs.close();
            }           
        } catch (SQLException e) {
        	throw new DatabaseException(
        					ErrorMessages.ERROR_DB_SELECT.getValue(), e);
        }
    }

}
