package edu.uoc.pfc.social.test;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.util.List;

import org.junit.Before;
import org.junit.Test;

import edu.uoc.pfc.profile.data.Profile;
import edu.uoc.pfc.profile.exception.ProfileException;
import edu.uoc.pfc.profile.xml.ProfileXMLHelper;
import edu.uoc.pfc.profile.xml.ProfileXMLParser;
import edu.uoc.pfc.social.SocialNetwork;
import edu.uoc.pfc.social.data.SocialNetworkProfileMapper;
import edu.uoc.pfc.social.data.SocialNetworkProfileXMLHelper;
import edu.uoc.pfc.social.exception.DatabaseException;
import edu.uoc.pfc.social.exception.SocialNetworkException;
import edu.uoc.pfc.user.data.User;
import edu.uoc.pfc.user.data.UserList;

public class SocialNetworkTest {

	final static String DB_FOLDER = "./resources/db/";
	
	final static String LOGS_FOLDER = "./logs/";
	
	private static InputStream socialNetworkXml;
	
	private static InputStream dbProperties;
	
	@Before
	public void setUpBeforeClass() throws IOException, DatabaseException {
		String socialPath = DB_FOLDER + "socialnetwork_2.xml";
		String dbPropsPath = DB_FOLDER + "jdbc.oracle.properties";
		socialNetworkXml = new FileInputStream(socialPath);
		dbProperties = new FileInputStream(dbPropsPath);		
	}

	@Test
	public void testSocialNetworkInit() throws SocialNetworkException {
		SocialNetwork socialNetwork = new SocialNetwork(socialNetworkXml, dbProperties);
		socialNetwork.init();	
		socialNetwork.close();
	}
	
	@Test
	public void testProfileMapper() throws SocialNetworkException{
		SocialNetworkProfileMapper mapper = new SocialNetworkProfileMapper(dbProperties);
		Profile profile = mapper.getProfileFromUserAddress("192.168.1.33", "5555");
		UserList userList = profile.getContactList();
		List<User> contactList = userList.getSortedList();
		
		assertNotNull("Check if contactList is not null", contactList);
		assertEquals("Check if data is correct", "192.168.1.33:5555", profile.getUser().getUserId());
		showData(profile, contactList);				
	}
	
	@Test
	public void testProfileDownloader() throws SocialNetworkException, 
											   ProfileException, IOException{
		ProfileXMLHelper helper = new SocialNetworkProfileXMLHelper(dbProperties);
		File file = new File(LOGS_FOLDER + "profile.xml");
		Profile profile = helper.downloadProfile("192.168.1.33", "5555", file);
		UserList userList = profile.getContactList();
		List<User> contactList = userList.getSortedList();
		
		assertNotNull("Check if contactList is not null", contactList);
		assertEquals("Check if data is correct", "192.168.1.33:5555", profile.getUser().getUserId());
		showData(profile, contactList);		
	}

	@Test
	public void testProfileUpdater() throws SocialNetworkException, 
											ProfileException, IOException{
		ProfileXMLHelper helper = new SocialNetworkProfileXMLHelper(dbProperties);
		File file = new File(LOGS_FOLDER + "profile_values.xml");
		Profile profile = helper.updateProfile("192.168.1.33", "5555", file);
		UserList userList = profile.getContactList();
		List<User> contactList = userList.getSortedList();
		
		assertNotNull("Check if contactList is not null", contactList);
		assertEquals("Check if data is correct", "192.168.1.33:5555", profile.getUser().getUserId());
		showData(profile, contactList);		
	}
	
	@Test
	public void testProfileFromXML() throws ProfileException{
		ProfileXMLParser parser = new ProfileXMLParser();
		File file = new File(LOGS_FOLDER + "profile_values.xml");
		Profile profile = parser.profileFromXMLFile(file);
		UserList userList = profile.getContactList();
		List<User> contactList = userList.getSortedList();
		
		assertNotNull("Check if contactList is not null", contactList);
		assertEquals("Check if data is correct", "192.168.1.33:5555", profile.getUser().getUserId());
		showData(profile, contactList);		
	}
	
	private void showData(Profile profile, List<User> contactList) {
		for(User user : contactList){
			System.out.println(user.getUserId());
		}
		System.out.println(profile.getUser().getUserId());
		System.out.println(profile.getUser().getCert());
		System.out.println(profile.getUser().getP());
		System.out.println(profile.getUser().getT());
		System.out.println(profile.getUser().getTau());
	}

}
