package edu.uoc.pfc.submitting.test;

import static org.junit.Assert.*;

import org.junit.BeforeClass;
import org.junit.Test;

import edu.uoc.pfc.submitting.QuerySubmittingHelper;
import edu.uoc.pfc.user.data.User;
import edu.uoc.pfc.user.data.UserList;

public class QuerySubmittingHelperTest {

	private static User user1;
	private static User user2;
	private static User user3;
	private static User user4;
	private static User user5;
	
	@BeforeClass
	public static void setUpBeforeClass() throws Exception {
		
		// Creaci dels usuaris
		user1 = new User();
		user1.setUserId("user1");
		user1.setTau(67);
		user1.setT(34);
		user1.setP(0.45);		
		// Resultats dels clculs: alpha: 16.75  - beta: 4
						
		user2 = new User();
		user2.setUserId("user2");
		user2.setTau(56);
		user2.setT(78);
		user2.setP(0.34);		
		// Resultats dels clculs: alpha: 56.0 - beta: 1
				
		user3 = new User();
		user3.setUserId("user3");
		user3.setTau(63);
		user3.setT(23);
		user3.setP(0.35);		
		// Resultats dels clculs: alpha: 12.6 - beta: 5
				
		user4 = new User();
		user4.setUserId("user4");
		user4.setTau(45);
		user4.setT(35);
		user4.setP(0.23);
		// Resultats dels clculs: alpha: 15.0 - beta: 3
				
		user5 = new User();
		user5.setUserId("user5");
		user5.setTau(42);
		user5.setT(54);
		user5.setP(0.34);		
		// Resultats dels clculs: alpha: 21.0 - beta: 2
	}

	@Test
	public void testProfileExposureEstimationOK() {
		// Inicialitzaci de la llista d'usuaris.
		UserList userList = new UserList();
		userList.add(user1.getUserId(), user1);
		userList.add(user5.getUserId(), user5);
		userList.add(user2.getUserId(), user2);
		userList.add(user4.getUserId(), user4);
		userList.add(user3.getUserId(), user3);
		
		//Obtenci de l'usuari al qual li ser enviada la consulta
		QuerySubmittingHelper querySubmiting = new QuerySubmittingHelper();
		User selectedUser = querySubmiting.profileExposureEstimation(userList);
		
		// Comprovacions
		assertEquals("Check if the selected user is the expected user", user3.getUserId(), selectedUser.getUserId());
	}
	
	@Test
	public void testProfileExposureEstimationEmptyList() {
		// Inicialitzaci de la llista d'usuaris buida.
		UserList userList = new UserList();
				
		//Obtenci de l'usuari al qual li ser enviada la consulta
		QuerySubmittingHelper querySubmiting = new QuerySubmittingHelper();
		User selectedUser = querySubmiting.profileExposureEstimation(userList);
		
		// Comprovacions
		assertNull("Check if the selected user is null", selectedUser);
	}
	
	@Test
	public void testSelfishnessEvaluationOK() {
		// Inicialitzaci de la llista d'usuaris.
		UserList userList = new UserList();
		userList.add(user1.getUserId(), user1);
		userList.add(user5.getUserId(), user5);
		userList.add(user2.getUserId(), user2);
		userList.add(user4.getUserId(), user4);
		userList.add(user3.getUserId(), user3);
		
		// Valors esperats resultat de fer els clculs prviament 
		Double expectedT = new Double(user1.getT()+1);
		Double acceptExpectedP =  new Double(user1.getP() - QuerySubmittingHelper.GAMMA);
		Double rejectExpectedP =  new Double(user1.getP());		
		
		//Obtenci la avaluaci del nivell d'egoisme
		QuerySubmittingHelper querySubmiting = new QuerySubmittingHelper();
		boolean accept = querySubmiting.selfishnessEvaluation(user1, userList);
		
		User user = userList.get(user1.getUserId());
		
		// Comprovacions
		if(accept){
			assertEquals("Check if probability is the expected", acceptExpectedP, 
						 new Double(user.getP()));				
		} else {
			assertEquals("Check if probability is the expected", rejectExpectedP, 
						 new Double(user.getP()));					
		}
		assertEquals("Check if t is the expected", expectedT, new Double(user.getT()));		
	}
	
	@Test
	public void testSelfishnessEvaluationEmptyList() {
		// Inicialitzaci de la llista d'usuaris buida.
		UserList userList = new UserList();
				
		//Obtenci la avaluaci del nivell d'egoisme
		QuerySubmittingHelper querySubmiting = new QuerySubmittingHelper();
		boolean accept = querySubmiting.selfishnessEvaluation(user1, userList);
		
		//Comprovacions
		assertFalse("Check if t query is rejected", accept);		
	}
	
	@Test
	public void testUpdateAcceptanceProbabilityTrueOK() {
		// Inicialitzaci de la llista d'usuaris.
		UserList userList = new UserList();
		userList.add(user1.getUserId(), user1);
		userList.add(user5.getUserId(), user5);
		userList.add(user2.getUserId(), user2);
		userList.add(user4.getUserId(), user4);
		userList.add(user3.getUserId(), user3);
		
		// Valors esperats resultat de fer els clculs prviament 
		Double acceptExpectedP =  new Double(user1.getP() + 2 * QuerySubmittingHelper.GAMMA);
				
		//Obtenci la avaluaci del nivell d'egoisme
		QuerySubmittingHelper querySubmiting = new QuerySubmittingHelper();
		querySubmiting.updateAfterQuery(user1, user1, userList, true);
		
		User user = userList.get(user1.getUserId());
		
		// Comprovacions
		assertEquals("Check if probability is the expected", acceptExpectedP, 
						 new Double(user.getP()));			
			
	}
	
	@Test
	public void testUpdateAcceptanceProbabilityFalseOK() {
		// Inicialitzaci de la llista d'usuaris.
		UserList userList = new UserList();
		userList.add(user1.getUserId(), user1);
		userList.add(user5.getUserId(), user5);
		userList.add(user2.getUserId(), user2);
		userList.add(user4.getUserId(), user4);
		userList.add(user3.getUserId(), user3);
		
		// Valors esperats resultat de fer els clculs prviament 
		Double acceptExpectedP = new Double(user1.getP() - QuerySubmittingHelper.GAMMA);
				
		//Obtenci la avaluaci del nivell d'egoisme
		QuerySubmittingHelper querySubmiting = new QuerySubmittingHelper();
		querySubmiting.updateAfterQuery(user1, user1, userList, false);
		
		User user = userList.get(user1.getUserId());
		
		// Comprovacions
		assertEquals("Check if probability is the expected", acceptExpectedP, 
						 new Double(user.getP()));			
			
	}

}
