package edu.uoc.pfc.transaction.test;

import static org.junit.Assert.*;

import org.junit.BeforeClass;
import org.junit.Test;

import edu.uoc.pfc.transaction.data.TransactionCertificate;
import edu.uoc.pfc.transaction.data.TransactionCertificateSerializer;

public class TransactionCertificateSerializerTest {

	private static TransactionCertificateSerializer serializer; 
			
	private static TransactionCertificate tc;
	
	private static String tcSerialDecoded;
	
	private static String tcSerial;
	
	
	@BeforeClass
	public static void setUpBeforeClass() {
		
		// Inicialitzaci del serialitzador
		serializer = new TransactionCertificateSerializer();
				
		// Inicialitzaci del objecte de dades.
		tc = new TransactionCertificate();
		tc.setQ("Query");
		tc.setUserSrc("user1");
		tc.setUserDst("user2");
		tc.setTimestamp(String.valueOf("1319985033608"));
		
		// Inicialitzaci del valor del objecte de dades serialitzat decodificat.
		tcSerialDecoded = "Query||user1||user2||1319985033608"; 
		
		// Inicialitzaci del valor del objecte serialitzat.
		tcSerial = "UXVlcnl8fHVzZXIxfHx1c2VyMnx8MTMxOTk4NTAzMzYwOA=="; 
		
	}
	
	@Test
	public void testSerializeOK() {				
		//Serializaci del objecte
		byte[] serial = serializer.serialize(tc);
		String serialStr = new String(serial);
				
		// Comprovacions
		assertEquals("Check if Serialization is OK: ", tcSerial, serialStr);
	}
	
	@Test
	public void testSerializeSerializationError() {		
		// Creaci d'un objecte serialitzat incorrecte
		String wrongSerialStr = "V3JvbmcgUXVlcnl8fHVzZXI0fHx1c2VyNXx8MTMxOTk4NTAzMzYxNQ==";
		
		// Comprovacions
		assertFalse("Check if Serialization is wrong: ", tcSerial.equals(wrongSerialStr));		
	}
	
	@Test
	public void testSerializeError() {		
		// Creaci d'un objecte de dades incorrecte
		TransactionCertificate tcWrong = new TransactionCertificate();
		tcWrong = new TransactionCertificate();
		tcWrong.setQ("Wrong Query");
		tcWrong.setUserSrc("user4");
		tcWrong.setUserDst("user5");
		tcWrong.setTimestamp(String.valueOf("1319985033615"));
		
		// Serialitzaci del objecte de dades incorrecte
		byte[] wrongSerial = serializer.serialize(tcWrong);
		String wrongSerialStr = new String(wrongSerial);
		
		// Comprovacions
		assertFalse("Check if data objecte is wrong: ", tcSerial.equals(wrongSerialStr));		
	}
	
	@Test
	public void testDeserializeOK() {
		// Deserialitzaci del objecte de dades		
		TransactionCertificate tcDeserial = 
						serializer.deserialize(tcSerial.getBytes());
		
		// Comprovacions
		assertEquals("Check if Query is OK: ", 
						tc.getQ(), tcDeserial.getQ());
		assertEquals("Check if UserSrc is OK: ", 
						tc.getUserSrc(), tcDeserial.getUserSrc());
		assertEquals("Check if UserDst is OK: ", 
						tc.getUserDst(), tcDeserial.getUserDst());
		assertEquals("Check if Timestamp is OK: ", 
						tc.getTimestamp(), tcDeserial.getTimestamp());		
	}
	
	@Test
	public void testDeserializeError() {
		// Creaci d'un objecte de dades serialitzat incorrecte
		String wrongSerialStr = "V3JvbmcgUXVlcnl8fHVzZXI0fHx1c2VyNXx8MTMxOTk4NTAzMzYxNQ==";
		
		// Deserialitzaci del objecte de dades		
		TransactionCertificate tcDeserial = 
						serializer.deserialize(wrongSerialStr.getBytes());
		
		// Comprovacions	
		assertFalse("Check if Query is wrong: ", 
						tc.getQ().equals(tcDeserial.getQ()));
		assertFalse("Check if UserSrc is wrong: ", 
						tc.getUserSrc().equals(tcDeserial.getUserSrc()));
		assertFalse("Check if UserDst is wrong: ", 
						tc.getUserDst().equals(tcDeserial.getUserDst()));
		assertFalse("Check if Timestamp is wrong: ", 
						tc.getTimestamp().equals(tcDeserial.getTimestamp()));		
	}
	
	@Test
	public void testDeserializeNullError() {
		// Creaci d'un objecte de dades serialitzat incorrecte
		String wrongSerialStr = "XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX";
		
		// Deserialitzaci del objecte de dades		
		TransactionCertificate tcDeserial = 
						serializer.deserialize(wrongSerialStr.getBytes());
		
		// Comprovacions
		assertNull("Check if Deserialization is wrong: ", tcDeserial);
	}

	
	@Test
	public void testEncodeOK(){
		// Codificaci en Base64 de la cadena
		byte[] encoded = serializer.encode(tcSerialDecoded.getBytes());
		String encodedStr = new String(encoded);
		
		// Comprovacions
		assertEquals("Check if encoding is OK: ", tcSerial, encodedStr);		
	}
	
	@Test
	public void testEncodeError(){
		// Codificaci de una cadena incorrecta
		String tcSerialDecodedWrong = "Wrong Query||user3||user4||1319985033615"; 
		byte[] wrongEncoded = serializer.encode(tcSerialDecodedWrong.getBytes());
		String wrongEncodedStr = new String(wrongEncoded);
		
		// Comprovacions
		assertFalse("Check if encoding is wrong: ", tcSerial.equals(wrongEncodedStr));
	}
	
	@Test
	public void testDecodeOK(){
		// Decodificaci de la cadena en Base64
		byte[] decoded = serializer.decode(tcSerial.getBytes());
		String decodedStr = new String(decoded);
		
		// Comprovacions
		assertEquals("Check if decoding is OK: ", tcSerialDecoded, decodedStr);	
	}
	
	@Test
	public void testDecodeError(){
		// Decodificaci de una cadena en Base64 incorrecta
		String wrongSerialStr = "V3JvbmcgUXVlcnl8fHVzZXI0fHx1c2VyNXx8MTMxOTk4NTAzMzYxNQ==";
		byte[] wrongDecoded = serializer.decode(wrongSerialStr.getBytes());
		String wrongDecodedStr = new String(wrongDecoded);
		
		// Comprovacions
		assertFalse("Check if decoding is wrong: ", tcSerialDecoded.equals(wrongDecodedStr));
	}	
}
