
package edu.uoc.pfc.commons.security.msg;

/**
 * Enumeration on seran declarats tots els missatges d'error de les excepcions que es puguin produr
 * durant la manipulaci dels certificats o durant la generaci i validaci de les signatures 
 * electrniques del certificat de transacci. 
 * 
 * @author Rubn Salvador Gareta
 *
 */
public enum ErrorMessages {
	
	// Missatges d'error en la classe SignatureHelper
    ERROR_GETTING_BYTES("Error getting digital signature bytes."),
    ERROR_GENERATING_SIGNATURE("Error generating PKCS#7 digital signature."),    
    ERROR_VALIDATING_SIGNATURE("Error validating PKCS#7 digital signature."),
    ERROR_SETTING_SIGNER("Error setting signer info into PKCS#7 digital signature."),
    ERROR_GETTING_SIGNER("Error getting signer info from PKCS#7 digital signature."),
    ERROR_GETTING_DATA("Error getting signed data from PKCS#7 digital signature."),
    ERROR_SIGNATURE_CERT("Error in signature certificate format."),
       
    // Missatges d'error en la classe CertificateHelper
    ERROR_KEYSTORE_FORMAT("Error in keystore format."),
    ERROR_GETTING_KEY("Error getting private key from keystore."),
    ERROR_KEY_ALGORITHM("Error in key cryptographic algorithm."),
    ERROR_KEYSTORE_FILE("Error getting Keystore. File is not correct."),
    ERROR_KEYSTORE_CERTIFICATE("Error getting Keystore certificate."),
    ERROR_CERTIFICATE_FORMAT("Error in certificate format."),
    ERROR_KEYSTORE_OPEN("Error getting Keystore. File or password are not correct.");
       
   
    private final String value;

    /**
     * Mtode constructor.
     * 
     * @param value Valor amb el qual ha de ser inicialitzat el enumeration.
     */
    private ErrorMessages(final String value) {
        this.value = value;
    }

    /**
     * Mtode utilitzat per a consultar el valor d'alguna de les constants 
     * de l'enumeration.
     * 
     * @return Valor de l'enumerator consultat.
     */
    public String getValue() {
        return this.value;
    }

}
