package edu.uoc.pfc.profile.data;

import java.security.KeyStore;

import edu.uoc.pfc.user.data.User;
import edu.uoc.pfc.user.data.UserList;


/**
 * Classe encarregada d'emmagatzemar tota la informaci referent al
 * perfil de l'usuari que est executant la aplicaci.
 * 
 * @author Rubn Salvador Gareta
 *
 */
public class Profile {
	
	/**
	 * Dades de l'usuari que est executant la aplicaci.
	 */
	private User user;
	
	/**
	 * Objecte keystore que far servir l'usuari per a signar les seves
	 * consultes.
	 */
	private KeyStore keystore;
	
	/**
	 * Identificador del certificat i la clau privada de l'usuari dins del
	 * keystore.
	 */
	private String alias;
	
	/**
	 * Contrasenya d'accs a la clau privada de l'usuari emmagatzemada dins del
	 * keystore.
	 */
	private char[] password;
	
	/**
	 * Llista de contactes directes de l'usuari.
	 */
	private UserList contactList;
	
	/**
	 * Mtode constructor.
	 */
	public Profile() {
		
	}
	
	/**
	 * Mtode amb el qual s'obten les dades de l'usuari que est executant la aplicaci.
	 * 
	 * @return Dades de l'usuari que est executant la aplicaci.
	 */
	public User getUser() {
		return user;
	}

	/**
	 * Mtode amb el qual s'estableixen les dades de l'usuari que est executant la 
	 * aplicaci.
	 * 
	 * @param user Dades de l'usuari que est executant la aplicaci.
	 */
	public void setUser(User user) {
		this.user = user;
	}

	/**
	 * Mtode amb el qual s'obt el keystore que far servir l'usuari per a signar 
	 * les seves consultes.
	 * 
	 * @return Keystore que far servir l'usuari per a signar 
	 * les seves consultes.
	 */
	public KeyStore getKeystore() {
		return keystore;
	}

	/**
	 * Mtode amb el qual s'estableix el keystore que far servir l'usuari per a signar 
	 * les seves consultes.
	 * 
	 * @param keystore Keystore que far servir l'usuari per a signar les seves consultes.
	 */
	public void setKeystore(KeyStore keystore) {
		this.keystore = keystore;
	}

	/**
	 * Mtode amb el qual s'obt l'identificador del certificat i la clau privada 
	 * de l'usuari dins del keystore.
	 * 
	 * @return Identificador del certificat i la clau privada de l'usuari dins del
	 * keystore,
	 */
	public String getAlias() {
		return alias;
	}

	/**
	 * Mtode amb el qual s'estableix el identificador del certificat i la clau privada 
	 * de l'usuari dins del keystore.
	 * 
	 * @param alias Identificador del certificat i la clau privada de l'usuari dins 
	 * del keystore.
	 */
	public void setAlias(String alias) {
		this.alias = alias;
	}

	/**
	 * Mtode amb el qual s'obt la contrasenya d'accs a la clau privada de 
	 * l'usuari emmagatzemada dins del keystore.
	 * 
	 * @return Contrasenya d'accs a la clau privada de l'usuari emmagatzemada 
	 * dins del keystore.
	 */
	public char[] getPassword() {
		return password;
	}

	/**
	 * Mtode amb el qual s'estableix la contrasenya d'accs a la clau privada de 
	 * l'usuari emmagatzemada dins del keystore.
	 * 
	 * @param password Contrasenya d'accs a la clau privada de l'usuari emmagatzemada 
	 * dins del keystore.
	 */
	public void setPassword(char[] password) {
		this.password = password;
	}

	/**
	 * Mtode amb el qual s'obt la llista de contactes directes de l'usuari.
	 * 
	 * @return Llista de contactes directes de l'usuari.
	 */
	public UserList getContactList() {
		return contactList;
	}

	/**
	 * Mtode amb el qual s'estableix la llista de contactes directes de l'usuari.
	 * 
	 * @param contactList Llista de contactes directes de l'usuari.
	 */
	public void setContactList(UserList contactList) {
		this.contactList = contactList;
	}
			
}
