package edu.uoc.pfc.search;

import java.io.IOException;
import java.net.MalformedURLException;
import java.net.URL;
import java.net.URLConnection;

import edu.uoc.pfc.search.exception.SearchGeneratorException;
import edu.uoc.pfc.search.msg.ErrorMessages;

/**
 * Classe encarregada d'enviar consultes al motor de cerca Google amb el format
 * de les urls de consulta de Google i de tornar el resultat.
 * 
 * @author Rubn Salvador Gareta
 *
 */
public class GoogleSearchGenerator extends SearchGenerator{
	
	/**
	 * Domini de Google.
	 */
	public static String DOMAIN = "google";

	/**
	 * URL de cerca de Google.
	 */
	private static String GOOGLE = "http://www.google.com/search?q=";
	
	/**
	 * Propietat User-agent necessria per a que Google interpreti que
	 * s'est llenant la cerca des d'un navegador.
	 */
	private static String AGENT_PROP_KEY = "User-Agent";
	
	/**
	 * Valor que s'assignar a la propietat User-Agent.
	 */
	private static String AGENT_PROP_VALUE = "Browser";
		
	
	/**
	 * Mtode constructor.
	 */
	public GoogleSearchGenerator() {
		
	}
	
	/**
	 * Mtode encarregat de configurar la URL de consulta de Google
	 * i de tornar la resposta de la cerca sobre el motor de cerca.
	 * 
	 * @param query Cerque que l'usuari desitja realitzar.
	 * @return Resposta de la cerca.
	 * @throws SearchGeneratorException 
	 */
	public String getQueryResult(String query) throws SearchGeneratorException{
		String answer = null;		
		try{
			// Formateig de la consulta per treure espais en blanc.
			String formattedQuery = query.trim().replaceAll("\\s+", "+");
			String urlStr = GOOGLE + formattedQuery;
			
			// Connexi amb el cercador. S'ha d'afegir la propietat User-Agent
			// perqu Google no detecti que s'est enviant la consulta des d'una 
			//aplicaci en lloc de fer-se des d'un cercador.
			URL url = new URL(urlStr);
			URLConnection conn = url.openConnection();
			conn.setRequestProperty(AGENT_PROP_KEY, AGENT_PROP_VALUE);
			
			// Enviament de la consulta directament a la connexi oberta amb Google
			answer = sendQuery(conn);
			
		} catch (MalformedURLException e){
			throw new SearchGeneratorException(
					ErrorMessages.ERROR_URL_FORMAT.getValue(), e);
		} catch (IOException e) {
			throw new SearchGeneratorException(
					ErrorMessages.ERROR_SERVER.getValue(), e);
		}				
		return answer;		
	}
	
}
