package edu.uoc.pfc.service;

import java.net.MalformedURLException;
import java.rmi.Naming;
import java.rmi.RemoteException;
import java.rmi.registry.LocateRegistry;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import edu.uoc.pfc.profile.data.Profile;
import edu.uoc.pfc.profile.xml.ProfileXMLHelper;
import edu.uoc.pfc.search.SearchGenerator;
import edu.uoc.pfc.service.exception.AnonymousQueryServiceException;
import edu.uoc.pfc.service.msg.ErrorMessages;
import edu.uoc.pfc.service.msg.InfoMessages;
import edu.uoc.pfc.service.rmi.AnonymousQueriesRemote;
import edu.uoc.pfc.service.rmi.AnonymousQueriesRemoteImpl;

/**
 * Classe encarregada de possar en marxa el servei remot de enviament de 
 * consultes annimes entre usuaris en funci de l'identificador de 
 * l'usuari. 
 * 
 * @author Rubn Salvador Gareta
 *
 */
public class AnonymousQueriesService {
		
	/**
	 * Variable que ser utilitzada per a escriure missatges en el log de la aplicaci.
	 */
	private static final Logger LOGGER =
	        LoggerFactory.getLogger(AnonymousQueriesService.class);
	
	/**
	 * Mtode constructor
	 * 
	 */
	public AnonymousQueriesService(){
		
	}
	
	
	/**
	 * Mtode encarregat d'inicialitzar el servei a partir de les dades del perfil de l'usuari.
	 * 
	 * @param profile Objecte que cont les dades del perfil de l'usuari.
	 * @param search Generador de consultes contra el motor de cerca
	 * @param helper Objecte d'utilitats relacionades amb l'emmagatzemament del perfil en 
	 * el fitxer XML.
	 * @throws AnonymousQueryServiceException 
	 */
	public void start(Profile profile, SearchGenerator search, ProfileXMLHelper helper)
									throws AnonymousQueryServiceException{
		try{
			LOGGER.info(InfoMessages.SERVICE_CONFIG_START.getValue());
			
			// Obtenci de la adrea i del port del servei a partir 
			// de l'identificador de l'usuari.
			String url = profile.getUser().getUserId();
			String[] address = url.split(":");
			int port = Integer.parseInt(address[1]);		
			
			// Registre del servei remot.
			LOGGER.info(InfoMessages.SERVICE_ADDRESS.getValue(), url);
			LocateRegistry.createRegistry(port);
			AnonymousQueriesRemote remote = 
							new AnonymousQueriesRemoteImpl(profile, search, helper);
			Naming.rebind(AnonymousQueriesRemote.PROTOCOL + url + 
						  AnonymousQueriesRemote.SERVICE, remote);
			
			LOGGER.info(InfoMessages.SERVICE_CONFIG_FINISH.getValue());
			
		} catch (RemoteException e) {
			LOGGER.error(ErrorMessages.ERROR_CONNECTION.getValue(), e);
			throw new AnonymousQueryServiceException(ErrorMessages.ERROR_CONNECTION.getValue(), e);
		} catch (MalformedURLException e) {
			LOGGER.error(ErrorMessages.ERROR_URL_FORMAT.getValue(), e);
			throw new AnonymousQueryServiceException(ErrorMessages.ERROR_URL_FORMAT.getValue(), e);
		} 		
	}

}
