package edu.uoc.pfc.social.msg;

/**
 * Enumeration on seran declarats tots els missatges d'error que es faran servir a 
 * la classe SocialNetwork. 
 * 
 * @author Rubn Salvador Gareta
 *
 */
public enum ErrorMessages {
	
		// Missatges genrics de la classe que s'encarrega de generar la xarxa social.
		ERROR_PROFILE("User profile can not be retrieved from Social Network."),
		ERROR_INPUT_FILES("Input files have incorrect data or format."),
		ERROR_STORED_DATA("Stored data is not correct."),
		ERROR_DATABASE_CONNECT("Can not connect to database."),
		ERROR_DATABASE_DISCONNECT("Can not close connection with database."),
		ERROR_DATABASE_INSERT("Can not insert data in database."),
		ERROR_DATABASE_SELECT("Can not get data from database."),
	
		// Missatges d'error relacionats amb la obtenci de les dades de la 
		// xarxa social a partir del document XML.
		ERROR_SEARCH_ELEMENT("Error searching an element in the XML document."),
		ERROR_XML_DOCUMENT("Error in XML document format."),
		ERROR_XML_CONFIG("Error in XML parser configuration."),
				
		// Missatges d'error relacionats amb la base de dades.
		ERROR_DB_PROPERTIES("Error in database properties file format."),
		ERROR_DB_CONNECTION("Error opening connection with database."),
		ERROR_DB_CLOSE("Error closing connection with database."),
		ERROR_DB_ROLLBACK("Error cancelling insertion into database."),
		ERROR_DB_DATA("Error in data to insert."),		
		ERROR_DB_INSERT("Error inserting data into database."),
		ERROR_DB_INSERT_USERS("Error inserting Users into database."),
		ERROR_DB_INSERT_CONTACTS("Error inserting Contacts into database."),
		ERROR_DB_SELECT("Error getting data from database."),
		ERROR_DB_SELECT_USERS("Error getting Users from database."),
		ERROR_DB_SELECT_CONTACTS("Error getting Contacts from database."),
		USAGE("Usage: StartSocialNetwork /f <social network file absolute path> /d <db.properties absolute path>");
		
		private final String value;

	    /**
	     * Mtode constructor.
	     * 
	     * @param value Valor amb el qual ha de ser inicialitzat el enumeration.
	     */
	    private ErrorMessages(final String value) {
	        this.value = value;
	    }

	    /**
	     * Mtode utilitzat per a consultar el valor d'alguna de les constants 
	     * de l'enumeration.
	     * 
	     * @return Valor de l'enumerator consultat.
	     */
	    public String getValue() {
	        return this.value;
	    }
}
