package edu.uoc.pfc.transaction.data;

/**
 * Classe encarregada d'emmagatzemar les dades que contindr el certificat de 
 * transacci que ser enviat entre els usuaris durant les transaccions.
 * 
 * @author Rubn Salvador Gareta
 *
 */
public class TransactionCertificate {
	
	/**
	 * Mtode constructor de la classe.
	 */
	public TransactionCertificate() {
		
	}
	
	/**
	 * Consulta que es vol enviar.
	 */
	private String q;
	
	/**
	 * Identificador de l'usuari que vol enviar la consulta.
	 */
	private String userSrc;
	
	/**
	 * Identificador de l'usuari al qual es vol enviar la consulta.
	 */
	private String userDst;
	
	/**
	 * Instant de temps expressat en millisegons en el qual s'envia la consulta.
	 */
	private String timestamp;

	
	/**
	 * Mtode amb el qual s'obt la consulta q que ser enviada d'un usuari 
	 * a un altre.
	 * 
	 * @return Consulta q que ser enviada d'un usuari a un altre.
	 */
	public String getQ() {
		return q;
	}

	/**
	 * Mtode amb el qual s'estableix la consulta q que ser enviada d'un 
	 * usuari a un altre.
	 * 
	 * @param q Consulta q que ser enviada d'un usuari a un altre.
	 */
	public void setQ(String q) {
		this.q = q;
	}

	/**
	 * Mtode amb el qual s'obt l'identificador de l'usuari que envia la 
	 * consulta a un altre.
	 *  
	 * @return Identificador de l'usuari que envia la consulta a un altre.
	 */
	public String getUserSrc() {
		return userSrc;
	}

	/**
	 * Mtode amb el qual s'estableix l'identificador de l'usuari que envia 
	 * la consulta a un altre.
	 * 
	 * @param userSrc Identificador de l'usuari que envia la consulta a un 
	 * altre.
	 */
	public void setUserSrc(String userSrc) {
		this.userSrc = userSrc;
	}

	/**
	 * Mtode amb el qual s'obt l'identificador de l'usuari que rep la 
	 * consulta d'un altre.
	 * 
	 * @return Identificador de l'usuari que rep la consulta d'un altre.
	 */
	public String getUserDst() {
		return userDst;
	}

	/**
	 * Mtode amb el qual s'estableix l'identificador de l'usuari que rep la 
	 * consulta d'un altre.
	 * 
	 * @param userDst Identificador de l'usuari que rep la consulta d'un altre.
	 */
	public void setUserDst(String userDst) {
		this.userDst = userDst;
	}

	/**
	 * Mtode amb el qual s'obt el moment en el qual es produeix la transacci 
	 * expressat en milisegons.
	 * 
	 * @return Moment en el qual es produeix la transacci expressat en milisegons.
	 */
	public String getTimestamp() {
		return timestamp;
	}

	/**
	 * Mtode amb el qual s'estableix el moment en el qual es produeix la transacci 
	 * expressat en milisegons.
	 * 
	 * @param timestamp Moment en el qual es produeix la transacci expressat en 
	 * milisegons.
	 */
	public void setTimestamp(String timestamp) {
		this.timestamp = timestamp;
	}	
		
}
