package edu.uoc.pfc.transaction.data;

import org.bouncycastle.util.encoders.Base64;



/**
 * Classe encarregada de serialitzar i deserialitzar la estructura de dades que cont la informaci del
 * certificat de transacci de cara a facilitar la signatura electrnica de les dades que seran enviades
 * en les transaccions entre usuaris.  
 * 
 * @author Rubn Salvador Gareta
 *
 */
public class TransactionCertificateSerializer {

	public static String SEPARATOR="||";
	
	/**
	 * Mtode constructor de la classe.
	 */
	public TransactionCertificateSerializer(){ 
		
	}
	
	/**
	 * Mtode amb el qual a partir de la estructura de dades que cont la informaci del
	 * certificat de transacci, s'obt una representaci codificada en Base64.
	 * 
	 * @param tc Estructura de dades que cont la informaci del certificat de transacci.
	 * @return Representaci de les dades del certificat de transacci codificades en Base64.
	 */
	public byte[] serialize(TransactionCertificate tc){
		String serialized = tc.getQ().concat(SEPARATOR).concat(tc.getUserSrc())
				.concat(SEPARATOR).concat(tc.getUserDst()).concat(SEPARATOR)
				.concat(tc.getTimestamp());		
		return encode(serialized.getBytes());
	}
	
	
	/**
	 * Mtode amb el qual a partir d'una representaci de les dades del certificat de transacci 
	 * codificada en Base64, s'obt una estructura de dades que cont la informaci del certificat 
	 * de transacci.
	 * 
	 * @param tcSerial Representaci de les dades del certificat de transacci codificada en Base64.
	 * @return Estructura de dades que cont la informaci del certificat de transacci.
	 */
	public TransactionCertificate deserialize(byte[] tcSerial){
		TransactionCertificate tc = new TransactionCertificate();
		String serialized = new String(decode(tcSerial));
		String[] serializedFields = serialized.split("["+SEPARATOR+"]+");
		try{
			tc.setQ(serializedFields[0]);
			tc.setUserSrc(serializedFields[1]);
			tc.setUserDst(serializedFields[2]);
			tc.setTimestamp(serializedFields[3]);
		} catch(ArrayIndexOutOfBoundsException e){
			tc = null;
		}
		return tc;		
	}
	
	
	/**
	 * Mtode em el qual es codificaran unes dades en Base64.
	 * @param data Dades que es volen codificar en Base64.
	 * @return Resultat de la codificacin en Base64
	 */
	public byte[] encode(byte[] data){
		return Base64.encode(data);
	}
	
	/**
	 * Mtode em el qual es decodificaran unes dades en Base64.
	 * @param data Dades en Base64 que es volen codificar 
	 * @return Resultat de la decodificacin.
	 */	
	public byte[] decode(byte[] data){
		return Base64.decode(data);
	}

}
