package edu.uoc.pfc.user.data;

import java.security.cert.Certificate;

/**
 * Classe encarregada d'emmagatzemar les dades dels usuaris que seran necessries 
 * per al protocol d'enviament de consultes cap al motor de cerca.
 * 
 * @author Rubn Salvador Gareta
 *
 */
public class User {
	
	
	/**
	 * Identificador d'usuari del contacte.
	 */
	private String userId;
	
	/**
	 * Certificat de clau pblica del contacte.
	 */
	private Certificate cert;
	
	
	/**
	 * Nombre de consultes que el contacte ha acceptat de l'usuari.
	 */
	private long tau; 
	

	/**
	 * Nombre de consultes que el contacte ha intentat delegar en l'usuari.
	 */
	private long t;
	

	
	/**
	 * Probabilitat de l'usuari d'acceptar consultes procedents del contacte.
	 */
	private double p;
	
	
	/**
	 * Mtode constructor de la classe.
	 */
	public User(){
		
	}
	

	/**
	 * Mtode amb el qual s'obt l'identificador d'usuari del contacte.
	 * 
	 * @return Identificador d'usuari del contacte.
	 */
	public String getUserId() {
		return userId;
	}

	/**
	 * Mtode amb el qual s'estableix l'identificador d'usuari del contacte.
	 * 
	 * @param userId Identificador d'usuari del contacte.
	 */
	public void setUserId(String userId) {
		this.userId = userId;
	}
	
	
	/**
	 * Mtode amb el qual s'obt l certificat de clau pblica del contacte.
	 * 
	 * @return Certificat de clau pblica del contacte.
	 */
	public Certificate getCert() {
		return cert;
	}


	/**
	 * Mtode amb el qual s'estableix el certificat de clau pblica del contacte.
	 * 
	 * @param cert Certificat de clau pblica del contacte.
	 */
	public void setCert(Certificate cert) {
		this.cert = cert;
	}
	
	/**
	 * Mtode amb el qual s'obt el nombre de consultes que el contacte ha 
	 * acceptat de l'usuari.
	 * 
	 * @return Nombre de consultes que el contacte ha acceptat de l'usuari.
	 */
	public long getTau() {
		return tau;
	}


	/**
	 * Mtode amb el qual s'estableix el nombre de consultes que el contacte ha 
	 * acceptat de l'usuari.
	 * 
	 * @param tau Nombre de consultes que el contacte ha acceptat de l'usuari.
	 */
	public void setTau(long tau) {
		this.tau = tau;
	}
	
	/**
	 * Mtode amb el qual s'obt el nombre de consultes que el contacte ha 
	 * intentat delegar en l'usuari.
	 * 
	 * @return Nombre de consultes que el contacte ha intentat delegar en 
	 * l'usuari.
	 */
	public long getT() {
		return t;
	}


	/**
	 * Mtode amb el qual s'estableix el nombre de consultes que el contacte ha 
	 * intentat delegar en l'usuari.
	 * 
	 * @param t Nombre de consultes que el contacte ha intentat delegar en 
	 * l'usuari.
	 */
	public void setT(long t) {
		this.t = t;
	}


	/**h
	 * Mtode amb el qual s'obt la probabilitat de l'usuari d'acceptar consultes 
	 * procedents del contacte.
	 * 
	 * @return Probabilitat de l'usuari d'acceptar consultes procedents del 
	 * contacte.
	 */
	public double getP() {
		return p;
	}


	/**
	 * Mtode amb el qual s'estableix la probabilitat de l'usuari d'acceptar 
	 * consultes procedents del contacte. 
	 * 
	 * @param p Probabilitat de l'usuari d'acceptar consultes procedents 
	 * del contacte.
	 */
	public void setP(double p) {
		if(p < 0.0 ){
			this.p = 0.0;
		} else  if(p > 1.0) {
			this.p = 1.0;
		} else {
			this.p = p;
		}
	}
	

}
